@@ -383,17 +383,15 @@ operator<<(std::ostream& the_stream, const ContinuedFraction &cf) {
 }
 
 
-// Extrapolates the curve, for given values (step & max) and numbers of terms
+//Extrapolates the curve without adding the result from the initial experiment
 void
-ContinuedFraction::extrapolate_distinct(const vector<double> &counts_hist,
-                                        const double max_value, 
+ContinuedFraction::extrapolate_distinct(const double max_value, 
                                         const double step_size,
                                         vector<double> &estimates) const {
-  const double hist_sum = std::accumulate(counts_hist.begin(), counts_hist.end(), 0.0);
   estimates.clear();
-  estimates.push_back(hist_sum);
+  estimates.push_back(0);
   for (double t = step_size; t <= max_value; t += step_size)
-    estimates.push_back(hist_sum + t*operator()(t));
+    estimates.push_back(t*operator()(t));
 }
 
 
@@ -436,7 +434,7 @@ check_yield_estimates_stability(const vector<double> &estimates) {
   // make sure that the estimate is increasing in the time_step and
   // is below the initial distinct per step_size
   for (size_t i = 0; i < estimates.size(); ++i)
-	  if (!R_FINITE(estimates[i]))
+	  if (!(R_FINITE(estimates[i])) || estimates[i] < 0)
 		  return false;
   for (size_t i = 1; i < estimates.size(); ++i){
     if (estimates[i] < estimates[i - 1] ){
@@ -451,7 +449,6 @@ check_yield_estimates_stability(const vector<double> &estimates) {
   return true;
 }
 
-
 /*
  * Finds the optimal number of terms (i.e. degree, depth, etc.) of the
  * continued fraction by checking for stability of estimates at
@@ -469,22 +466,22 @@ ContinuedFractionApproximation::optimal_cont_frac_distinct(const vector<double>
 	  return empty;
   }
 
-  // counts_sum = number of total captures
-  double counts_sum  = 0.0;
-  for(size_t i = 0; i < counts_hist.size(); i++)
-    counts_sum += i*counts_hist[i];
-  
   vector<double> full_ps_coeffs;
   for (size_t j = 1; j <= max_terms; j++)
     full_ps_coeffs.push_back( counts_hist[j]*std::pow((double)(-1), (int)(j + 1)) );
 
   ContinuedFraction full_CF(full_ps_coeffs, diagonal_idx, max_terms);  
 
+  // counts_sum = number of total captures
+  double counts_sum  = 0.0;
+  for(size_t i = 0; i < counts_hist.size(); i++)
+    counts_sum += i*counts_hist[i];
+  
   // if max terms = 4, check only that degree
   if(max_terms == 4 || max_terms == 3 
      || max_terms == 5 || max_terms == 6){   
     vector<double> estimates;
-    full_CF.extrapolate_distinct(counts_hist, SEARCH_MAX_VAL, SEARCH_STEP_SIZE, 
+    full_CF.extrapolate_distinct(SEARCH_MAX_VAL, SEARCH_STEP_SIZE, 
 			                     estimates);
     // return the continued fraction if it is stable
     if (check_yield_estimates_stability(estimates))
@@ -501,7 +498,7 @@ ContinuedFractionApproximation::optimal_cont_frac_distinct(const vector<double>
       ContinuedFraction curr_cf 
 	= ContinuedFraction::truncate_degree(full_CF, curr_terms);
       vector<double> estimates;
-      curr_cf.extrapolate_distinct(counts_hist, SEARCH_MAX_VAL, SEARCH_STEP_SIZE,
+      curr_cf.extrapolate_distinct(SEARCH_MAX_VAL, SEARCH_STEP_SIZE,
 			                       estimates);
           
     // return the continued fraction if it is stable
@@ -515,3 +512,48 @@ ContinuedFractionApproximation::optimal_cont_frac_distinct(const vector<double>
    // no stable continued fraction: return null
   return ContinuedFraction();  
 }
+
+// find the optimal RFA for a given power series with coefficients ps_coeff
+ContinuedFraction
+ContinuedFractionApproximation::optimal_powerseries_to_cont_frac(
+                                  const std::vector<double> &ps_coeffs) const {
+  if (max_terms > ps_coeffs.size()) {
+	  ContinuedFraction empty;
+	  return empty;
+  }
+  
+  ContinuedFraction full_CF(ps_coeffs, diagonal_idx, max_terms);  
+  // if max terms = 4, check only that degree
+  if(max_terms == 4 || max_terms == 3 
+     || max_terms == 5 || max_terms == 6){   
+    vector<double> estimates;
+    full_CF.extrapolate_distinct(SEARCH_MAX_VAL, SEARCH_STEP_SIZE, estimates);
+    // return the continued fraction if it is stable
+    if (check_yield_estimates_stability(estimates))
+      return full_CF;
+  }
+  else{
+    //if max terms >= 8, start at 8 and check increasing cont frac's
+    //may change the starting terms for k > 1
+    size_t curr_terms = 0;
+    if(max_terms % 2 == 0)
+      curr_terms = 8;
+    else
+      curr_terms = 7;
+    while (curr_terms <= max_terms) {    
+      ContinuedFraction curr_cf 
+	= ContinuedFraction::truncate_degree(full_CF, curr_terms);
+      vector<double> estimates;
+      curr_cf.extrapolate_distinct(SEARCH_MAX_VAL, SEARCH_STEP_SIZE, estimates);
+          
+    // return the continued fraction if it is stable
+      if (check_yield_estimates_stability(estimates))
+	      return curr_cf;
+    
+      curr_terms += 2;
+    // if not cf not acceptable, increase degree
+    }
+  }
+   // no stable continued fraction: return null
+  return ContinuedFraction();  
+}
